/*$Id: fkRuleReference.h,v 1.5 2006/11/04 21:09:25 jwrobel Exp $*/

/* ***** BEGIN LICENSE BLOCK *****
 *  This file is part of Firekeeper.
 *
 *  Copyright (C) 2006 Jan Wrobel <wrobel@blues.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * ***** END LICENSE BLOCK ***** */

#ifndef FKRULEREFERENCE
#define FKRULEREFERENCE

#include "fkIRuleReference.h"
#include "Rule.h"

class fkRuleReference : public fkIRuleReference
{
public:
	NS_DECL_ISUPPORTS
        NS_DECL_FKIRULEREFERENCE


        fkRuleReference(const reference*);
	virtual ~fkRuleReference();
private:	
	const reference *ref;

};


#endif
